var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Command } from 'commander';
import { clirun, getSession } from 'myst-cli-utils';
import chalk from 'chalk';
import fetch from 'node-fetch';
import { normalize, ORCID_URL } from '..';
function fetchAuthor(session, id) {
    return __awaiter(this, void 0, void 0, function* () {
        const url = id.replace('https://openalex.org', 'https://api.openalex.org');
        session.log.debug(`Fetching infor from ${url}`);
        const resp = yield fetch(url);
        const data = (yield resp.json());
        return data;
    });
}
export function checkTemplate(session, name) {
    return __awaiter(this, void 0, void 0, function* () {
        const url = `https://api.openalex.org/autocomplete/authors?q=${name}`;
        session.log.debug(`Fetching query from ${url}`);
        const resp = yield fetch(url);
        const data = (yield resp.json());
        session.log.debug(JSON.stringify(data, null, 2));
        const relevant = data.results.filter(({ external_id }) => external_id === null || external_id === void 0 ? void 0 : external_id.includes(ORCID_URL));
        if (relevant.length === 0) {
            session.log.warn(`Did not find any results for query "${name}".`);
            return;
        }
        const authors = yield Promise.all(relevant.map((r) => __awaiter(this, void 0, void 0, function* () {
            const author = yield fetchAuthor(session, r.id);
            return { author, query: r };
        })));
        session.log.info(chalk.dim(`Found ${authors.length} result${authors.length > 1 ? 's' : ''} for "${name}" with an ORCID:\n`));
        authors.forEach((result) => {
            var _a, _b;
            session.log.info(`${chalk.green.bold(result.author.display_name)}`);
            session.log.info(`${chalk.blue.bold(normalize(result.author.orcid))}`);
            session.log.info(`  Hint: ${chalk.dim(result.query.hint)}`);
            session.log.info(`  Last Institution: ${chalk.dim((_b = (_a = result.author.last_known_institution) === null || _a === void 0 ? void 0 : _a.display_name) !== null && _b !== void 0 ? _b : 'Unknown')}`);
            session.log.info(`  Concepts: ${chalk.dim(result.author.x_concepts
                .map((c) => c.display_name)
                .slice(0, 10)
                .join(', '))}`);
        });
    });
}
function makeSearchCLI(program) {
    const command = new Command('search')
        .description('Check that a template passes validation')
        .argument('<name>', 'Path to the template directory')
        .action(clirun(checkTemplate, { program, getSession }));
    return command;
}
export function addSearchCLI(program) {
    program.addCommand(makeSearchCLI(program));
}
